# KiBot (formerly KiPlot)

![KiBot Logo](https://raw.githubusercontent.com/INTI-CMNB/KiBot/dev/docs/images/kibot_740x400_logo.png)

[![Python application](https://img.shields.io/github/actions/workflow/status/INTI-CMNB/KiBot/pythonapp.yml?branch=master&style=plastic&logo=github)](https://github.com/INTI-CMNB/KiBot/actions)
[![Coverage Status](https://img.shields.io/coveralls/github/INTI-CMNB/KiBot?style=plastic&logo=coveralls&branch=master)](https://coveralls.io/github/INTI-CMNB/KiBot?branch=dev)
[![PyPI version](https://img.shields.io/pypi/v/kibot?style=plastic&logo=pypi)](https://pypi.org/project/kibot/)
[![DOCs status](https://img.shields.io/readthedocs/kibot?style=plastic&logo=readthedocs)](https://kibot.readthedocs.io/en/stable/)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg?style=plastic&logo=paypal)](https://www.paypal.com/donate/?hosted_button_id=K2T86GDTTMRPL)

KiBot is a program which helps you to generate the fabrication and
documentation files for your KiCad projects easily, repeatable, and most
of all, scriptably. This means you can use a Makefile to export your
KiCad PCBs just as needed, or do it in a CI/CD environment.

For more information consult the [documentation](https://kibot.readthedocs.io/en/master/) (hosted by Read the Docs)

If you are looking for the last features and fixes visit the [dev branch](https://github.com/INTI-CMNB/KiBot/tree/dev)

If you want to see an example of what KiBot can generate visit this
[project](https://inti-cmnb.github.io/kibot_variants_arduprog_site/Browse/t1-navigate.html)

If this is the first time you read about KiBot, and you prefer to be
introduced listening to a podcast, you can try the following
(english audio, english and spanish subtitles available):

[![General podcast](https://img.youtube.com/vi/6eYtJ9xiS1U/0.jpg)](https://www.youtube.com/watch?v=6eYtJ9xiS1U)


Here is another podcast, more centered on the CI/CD side:

[![CI/CD podcast](https://img.youtube.com/vi/BgSvupdpGvo/0.jpg)](https://www.youtube.com/watch?v=BgSvupdpGvo)
